import Vue from "vue";
import VueRouter from "vue-router";

Vue.use(VueRouter);

const routes = [
  {
    path: "/login",
    name: "login",
    component: () => import("../views/login/index.vue"),
    meta: { title: "登录", noAuth: true }, // 标记为免登录页面
  },
  {
    // 权限页面
    path: "/permission",
    name: "permission",
    component: () =>
      import(/* webpackChunkName: "permission" */ "../Permission.vue"),
    meta: { title: "权限测试" },
  },
  {
    path: "/",
    redirect: "/home",
    component: () => import("../components/Home.vue"),
    children: [
      {
        path: "/home",
        component: () => import("../views/homePage/index.vue"),
        name: "home",
        meta: {
          title: "首页",
          keepAlive: true,
          noAuth: true,
        },
      },
      {
        path: "/report",
        component: () => import("../views/report/index.vue"),
        name: "report",
        meta: {
          title: "状态报表",
          //keepAlive: true,
        },
      },
      {
        path: "/log",
        component: () => import("../views/logList/index.vue"),
        name: "log",
        meta: {
          title: "日志列表",
          keepAlive: true,
        },
      },
      {
        path: "/upgradation",
        component: () => import("../views/upgradation/index.vue"),
        name: "upgradation",
        meta: {
          title: "上传Apk",
          keepAlive: true,
        },
      },

      {
        path: "/activity",
        component: () => import("../views/activityList/index.vue"),
        name: "activity",
        meta: {
          title: "活动列表",
          keepAlive: true,
        },
      },
      {
        path: "/msgAuth",
        component: () => import("../views/msgAuth/index.vue"),
        name: "msgAuth",
        meta: {
          title: "短信授权",
          keepAlive: true,
        },
      },
      {
        path: "/deviceConfig",
        component: () => import("../views/deviceConfig/index.vue"),
        name: "deviceConfig",
        meta: {
          title: "设备配置",
          keepAlive: true,
        },
      },
      {
        path: "/picReport",
        component: () => import("../views/picReport/index.vue"),
        name: "picReport",
        meta: {
          title: "在线率报表",
          keepAlive: true,
        },
      },
      {
        path: "/historyReport",
        component: () => import("../views/historyReport/index.vue"),
        name: "historyReport",
        meta: {
          title: "运维历史数据",
          keepAlive: true,
        },
      },
      // {
      //   path: "/userlist",
      //   component: () => import("../views/userList/index.vue"),
      //   name: "userList",
      //   meta: {
      //     title: "用户列表",
      //     keepAlive: true,
      //   },
      // },
    ],
  },
];

const router = new VueRouter({
  mode: "hash",
  base: process.env.BASE_URL,
  routes,
});

export default router;
